@@ -4,9 +4,10 @@ from xarray import DataArray
 from .util import BaseMeta, SpatialTransform
 from typing import Optional
 
+
 @dataclass
 class ScaleMeta(BaseMeta):
-    path: str 
+    path: str
     transform: SpatialTransform
 
 
@@ -21,9 +22,18 @@ class GroupMeta(BaseMeta):
     multiscales: Sequence[MultiscaleMeta]
 
     @classmethod
-    def fromDataArraySequence(cls, dataarrays: Sequence[DataArray], paths: Sequence[str]):
+    def fromDataArraySequence(
+        cls, dataarrays: Sequence[DataArray], paths: Sequence[str]
+    ):
         name: str = str(dataarrays[0].name)
-        multiscales = [MultiscaleMeta(datasets=[ScaleMeta(path=path, transform=SpatialTransform.fromDataArray(arr)) for path, arr in zip(paths, dataarrays)])]
+        multiscales = [
+            MultiscaleMeta(
+                datasets=[
+                    ScaleMeta(path=path, transform=SpatialTransform.fromDataArray(arr))
+                    for path, arr in zip(paths, dataarrays)
+                ]
+            )
+        ]
         return cls(name=name, multiscales=multiscales)
 
 
@@ -35,4 +45,3 @@ class ArrayMeta(BaseMeta):
     @classmethod
     def fromDataArray(cls, data: DataArray) -> "ArrayMeta":
         return cls(name=str(data.name), transform=SpatialTransform.fromDataArray(data))
-        
\ No newline at end of file
